## Version 2.1 (November 2023)
- Maximum likelihood fitting of power spectrum and cross spectrum across multiple (stacked) light curves
- Include absorption and instrument ARFs for more realistic spectral timing simulations
- Convert time axes between MET for different X-ray missions
- Include background in light curves from XMM-Newton
- Compatibility with Python 3.12 and Numpy 1.24
- Various bug fixes and enhancements

## Version 2.0
- First public release